/* libgnome/libgnomemmconfig.h.  Generated from libgnomemmconfig.h.in by configure.  */
#ifndef _LIBGNOMEMM_CONFIG_H
#define _LIBGNOMEMM_CONFIG_H 1

#include "gtkmmconfig.h"

/* version numbers */
#define LIBGNOMEMM_MAJOR_VERSION 2
#define LIBGNOMEMM_MINOR_VERSION 28
#define LIBGNOMEMM_MICRO_VERSION 0
#define LIBGNOMEMM_VERSION "2.28.0"

#endif /* _LIBGNOMEMM_CONFIG_H */

